\name{pca}
\alias{pca}
\title{
  Principal Component Analysis
}
\description{
  Calculates principal components from a matrix
}
\usage{
pca(mat, cent = TRUE, scle = FALSE)
}
\arguments{
  \item{mat}{a numeric matrix.}
  
  \item{cent}{a logical value referring to center argument in \code{scale}.}
  
  \item{scle}{a logical value referring to scale argument in \code{scale}.}
}
\value{
  a list containing
  \item{pcs}{a matrix of principal component loadings}

  \item{d}{a matrix containing the singular value (eigenvalue) of each
    principal component on its diagonal}

  \item{v}{a matrix of eigenvectors}
}
\author{
  R port by Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} from S+
  library by Glenn De'ath \email{g.death@aims.gov.au}.
}
\examples{
         data(soilspec)
         species <- sqrt(soilspec[,2:9])
         specpca <- pca(species)
         eqscplot(specpca$pcs[,1], specpca$pcs[,2], type = "n",
              xlab = "Principal component 1",
              ylab = "Principal component 2") 
         text(specpca$pcs[,1], specpca$pcs[,2], 
              soilspec$site) 
         mtext(paste("Grassland communities in 45 sites"))
}
\keyword{multivariate}




\eof
\name{pcdiags.plt}
\alias{pcdiags.plt}
\alias{pcres1.plt}
\alias{pcres2.plt}
\alias{pcqqnorm.plt}
\alias{pcchisq.plt}
\alias{pcresid.plt}
\alias{pcfinder.plt}
\alias{pcresp.plt}
\alias{pcflip.plt}
\alias{finder}
\alias{pcdists.plt}
\alias{pchist.plt}
\alias{pcenv.plt}
\title{
  Diagnostic Plots for Principal Curve Analysis
}
\description{
A menu of 12 plots for diagnosis of results from principal curve
analysis, \code{pcurve}
}
\usage{
pcdiags.plt(zz, xx, pch = 1, graphics = TRUE)
}
\arguments{
\item{zz}{an object of class principal curve, being the value of the
  funtion \code{pcurve}.
}
\item{xx}{data.frame or matrix of explanatory (environmental) variables
  to be used in constrained pcs.
}
\item{pch}{symbol to be used in plots.
  }
\item{graphics}{a logical argument of \code{menu} indicating whether a graphics menu should be used. Currently unused.
}
}
\details{
Produces a menu of 12 (or thirteen if xx is not missing) options. Once a
selection is made, return to the menu by left-mouse clicking on the
plot.

0. Exit

1. Residuals plots for each variable on the PC (by the internal function
\code{pcres1.plt})

2. Absolute residuals plot for each variable on the PC (by the internal
function \code{pcres2.plt})

3. QQ normal residuals plot for each variable (by the internal function
\code{pcqqnorm.plt})

4. QQ chi-squared quantile residuals plot (by the internal function
\code{pcchisq.plt})

5. Response plot and residual plot for each variable (by the internal
function \code{pcresid.plt})

6. Differenced locations: Plot of distances between consecutive
locations on the PC (by the internal function \code{pcfinder.plt})

7. Response plots for each variable along the PC (by the internal
function \code{pcresp.plt})

8. Flip plots: Plot of the PC projected onto a bi-plot of the first two
principal coordinates, showing fitted locations of the variables on the
PC.  Left-mouse click to scroll through biplots of other principal
coordinate combinations. (Right-mouse-click to return to the menu)
(Using the internal function \code{pcflip.plt})

9. Fix curve: a utility to break the curve in up to two places (by left
mouse-clicks), re-order the segments and rerun the PC analysis with a
new start. (using the internal function \code{finder})

10. Scatterplots of Eclidean and Bray-Curtis distances against the
PC. (using the internal function \code{pcdists.plt})

11. Histograms of Eclidean and Bray-Curtis distances against the
PC. (using the internal function \code{pchist.plt})

12. A toggle to use Case numbers or symbols in plots

13. Env. vars. vs Gradient: if xx is not missing, plots of distance
along the PC and explanatory variables (using the internal function \code{pcenv.plt})
}
\value{Produces plots
}
\references{ 
De'ath, G. 1999 Principal Curves: a new technique for indirect and direct gradient analysis. \emph{Ecology} \bold{80}, 2237--2253.
}
\author{R port by Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} from S+
library by Glenn De'ath \email{g.death@aims.gov.au}.
}
\keyword{hplot}
\keyword{iplot}
\keyword{multivariate}
\keyword{smooth}





\eof
\name{pcurve}
\alias{pcurve}
\title{
  Principal Curve Analysis
}  
\description{
Fits a principal curve to a numeric multivariate dataset in arbitrary dimensions. Produces diagnostic plots.  
}
\usage{
pcurve(x, xcan = NULL, start = "ca", rank = FALSE, cv.fit = FALSE,
penalty= 1, cv.all = FALSE, df = "vary", fit.meth = "spline",
canfit = "lm",candf = FALSE, vary.adj = FALSE, subset,
robust = FALSE, lowf = 0.5, min.df, max.df, max.df.cv.fit,
ext.dist = TRUE, ext.dc = 0.9, metric = "bray", latent = FALSE,
plot.pca = TRUE, thresh = 0.001, plot.true = TRUE,
plot.init = FALSE, plot.segs = TRUE, plot.resp = TRUE,
plot.cov = TRUE, maxit = 10, stretch = 2, fits = FALSE,
prnt.fits = TRUE, trace = TRUE, trace.all = FALSE, pch = 1,
row.chk0 = FALSE, col.chk0 = TRUE, use.loc = FALSE)
 }
\arguments{
  \item{x}{numeric data matrix or data.frame.}
  
  \item{xcan}{data.frame or matrix of explanatory variables to be used in constrained PCs.}

  \item{start}{specifies how to determine the starting configuration (location of points on initial curve): "ca" = correspondence analysis; "pca" = principal components analysis with Euclidan metric;  "pca.bc" = principal components analysis with Bray-Curtis metric; "mds" = non-metric multidimensional scaling with Euclidean metric; "mds.bc" = non-metric multidimensional scaling with Bray-Curtis metric; "cs.bc" = classical scaling (metric multidimensional scaling) with Bray-Curtis metric; "ran" = random start.  Or if start is numeric and of length dim(x)[1] a user supplied configuration will be used.}
  
  \item{rank}{if TRUE starting configuration is transformed to rank}

  \item{cv.fit}{if TRUE a final iteration using cross-validation is done.}

  \item{penalty}{penalty for smoothing spline. A value of 1 corresponds
    to no penalty with values > 1 giving a less-smoothed fit. Increasing
    the penalty for small data sets can reduce over-fitting.  If penalty =
    "np", penalty = 1 for  N > 1000, penalty = 2 for N <=100, and
    penalty = 4-log(N, 10) for N  > 100 and N <= 1000.}

  \item{cv.all}{if TRUE a cross-validated smoothing spline fit at each iteration.}

  \item{df}{if numeric specifies the df for the smoothing spline.}
  
  \item{fit.meth}{specifies smoother. "spline" = smooth.spline, "poisson" = poisson general additive model, "binomial" = binomial general additive model, "lowess" = lowess smoother (this argument overridden by robust = TRUE).}

  \item{canfit}{"lm" or "gam", model used to relate pc to xcan.}

  \item{candf}{if canfit = "gam", df for model. May be a single value or
  a vector of FALSE or positive integers indicating dfs for each
  explanatory  variable in xcan.  If FALSE, this is equivalent to
  fx=FALSE in \code{gam}, and d.f. is selected by GCV.UBRE}

  \item{vary.adj}{if FALSE the same df are used for the smooth of each variable, otherwise each variable  has its own df.}

  \item{subset}{used to take a subset of x and start (if numeric).}

  \item{robust}{if TRUE uses lowess smooths, if FALSE uses smoothing spline.}

  \item{lowf}{specifies the span of the lowess smooth.}

  \item{min.df}{specifies the min df for the smoothing.}

  \item{max.df}{specifies the max df for the smoothing.}

  \item{max.df.cv.fit}{}
  
  \item{ext.dist}{if TRUE extended dissimilarities in calculation of
    initial configuration using the flexible shortest path. If FALSE
    standard dissimilarites are used (see De'ath, 1999b and
    \code{stepacross} in package vegan).}

  \item{ext.dc}{critical distance, the toolong argument in \code{stepacross}.}

  \item{metric}{similarity metric, the method argument in \code{vegdist}
    in package vegan.}

  \item{latent}{if FALSE locations are rescaled after each iteration to give distance along the curve; if TRUE no rescaling is done.}

  \item{plot.pca}{if TRUE the fitting is plotted (assuming plot.true = TRUE) in the first 2  dimensions of PCA space.}
  
  \item{thresh}{threshold value of difference in cross-validation for ceasing iteration}
  
  \item{plot.true}{if TRUE the fitting process is plotted.}

  \item{plot.init}{ if TRUE the initial fits to each variable are plotted.}

  \item{plot.segs}{if TRUE segments linking the fitted points on the curves to their corresponding data points are plotted.}

  \item{plot.resp}{if TRUE the final response curves are plotted.}

  \item{plot.cov}{if TRUE covariate partial effects are plotted (only if xcan is not null).}

  \item{maxit}{specifies the maximin number of iterations.}

  \item{stretch}{end segments of the curve are stretched by this factor at each iteration.}

  \item{fits}{if TRUE value of pcurve includes diagnostics for each variable.}

  \item{prnt.fits}{statistics on model fits printed.}

  \item{trace}{prints out useful fitting diagnostics at each iteration.}

  \item{trace.all}{if TRUE prints out all curve details at each iteration.}

  \item{pch}{symbol for plots}

  \item{row.chk0}{if TRUE checks for and removes rows of x identically 0.}

  \item{col.chk0}{if TRUE checks for and removes columns of x identically 0.}

  \item{use.loc}{if TRUE pauses during the fitting displays (left mouse-click to progress to next plot).}
}
\details{
See De'ath (1999a) for a full discussion of the functions and their application.
}
\value{
  An object of class principal curve containing a list comprising

  \item{s}{fitted values}
  
  \item{tag}{order of points along the curve}

  \item{lambda}{locations along the curve}

  \item{dist}{sum of squared distances of points from the curve}

  \item{c}{call to pcurve}

  \item{x}{data to which the curve was fitted}

  \item{df}{degrees of freedom for the smoothers used in the fit}

  \item{fit.list}{diagnostics for each variable, only included if fits = TRUE.}
}
\references{
  
De'ath, G. 1999a Principal Curves: a new technique for indirect and direct gradient analysis. \emph{Ecology} \bold{80}, 2237--2253.

De'ath, G. 1999b Extended dissimilarity: method of robust estimation of ecological distances with high beta diversity. \emph{Plant Ecology} \bold{144}, 191--199.

Gittins, R. 1985 \emph{Canonical Analysis.  A review with applications in ecology.}  Berlin: Springer-Verlag.

Hastie, T.J and Tibshirani, R.J. 1990 \emph{Generalized additive models.} London: Chapman and Hall.

Hastie, T.J. and Stuetzle, W. 1989 Principal Curves. \emph{Journal of the American Statistical Association} \bold{84}, 502--516.
}
\author{
R port by Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} from S+ library by Glenn De'ath \email{g.death@aims.gov.au}. Original S code for principal curve analysis by Trevor Hastie \email{hastie@stat.stanford.edu}.
}
\seealso{\code{\link{pcdiags.plt}}, \code{\link[vegan]{vegdist}},  \code{\link[vegan]{stepacross}}}
\examples{
#a simulated dataset with 4 response variables (taxa 1-4),
#n=100.  The response curve is Gaussian and noise is Poisson.
    data(sim4var)
    sim4fit <-  pcurve(sim4var, plot.init = FALSE, use.loc = TRUE)

#Limestone grassland community example worked by De'ath (1999a),
#from data in Gittins (1985)
    data(soilspec)
    species <- sqrt(soilspec[,2:9])
    envvar <- soilspec[,10:12]
#indirect gradient analysis
    spec.fit <- pcurve(species, start = "mds.bc", plot.init = FALSE,
                       use.loc = TRUE)
#direct gradient analysis
    soilspec.fit <- pcurve(species, xcan = envvar, 
                           start = "mds.bc", plot.init = FALSE,  
                           fits = TRUE, prnt.fits = TRUE,
                           use.loc = TRUE)
}
\keyword{multivariate}
\keyword{smooth}
\keyword{loess}
\keyword{hplot}

\eof
\name{pcurve.data}
\alias{sim4var}
\alias{sim10var}
\alias{soilspec}
\alias{fish}
\title{
  Example data for pcurve
}
\description{
  Example data sets for pcurve package.
  }
\usage{
  data(sim4var)
  data(sim10var)
  data(fish)
  data(soilspec)
}
\details{
    sim4var.txt

    Simulated data. Comprises 4 response variables (Taxa1 - Taxa4) and
    the generating locations (Location).  Number of cases = 100.  This
    example was worked by De'ath (1999).  The response curves are
    Gaussian and noise is Poisson.  Most starting configurations are
    adequate, square root transformation helps.

  
    sim10var.txt

    Simulated data. Comprises 10 response variables
    (Taxa1 - Taxa10) and the generating locations (Location).  Number
    of cases = 100. The response curves are Gaussian and noise is
    Poisson.  The beta-diversity is high and recovering the generating
    locations is difficult.
    A more difficult exercise.  Transformation is a must (square-root
    is ok).  Many starting configurations fail.  CA or MDS-BC succeed
    with appropriate smoothness.


    fish.txt

    Comprises counts on 10 families of reef fish
    (n = 33) and a factor variable IMO denoting the position of the
    sites across the reef.  Log-transformation is effective and a
    final cross-validation helps improve the fit.  The locations
    vary systematically with cross shelf position (IMO).


    soilspec.txt

    Comprises data on 8 species of plants and 3
    soil characteristics and their interactions.
    Source Gittins (1985), where a relatively complex canonical
    analysis was used to model the data.
    This example was worked by De'ath (1999).
}
\references{
  
De'ath, G. 1999 Principal Curves: a new technique for indirect and direct gradient analysis. \emph{Ecology} \bold{80}, 2237--2253.

Gittins, R. 1985 \emph{Canonical Analysis.  A review with applications in ecology.}  Berlin: Springer-Verlag.
}
\author{
  R port by Chris Walsh \email{Chris.Walsh@sci.monash.edu.au} from S+
  library by Glenn De'ath \email{g.death@aims.gov.au}.
}
\keyword{datasets}








\eof
\name{pcurve.internal}
\alias{pcget.lam}
\alias{startPC}
\alias{cavecs}
\alias{mdsform}
\alias{gdsqform}
\alias{n.plt}
\alias{print.gd}
\alias{scaleto1}
\title{
  Internal functions for pcurve
}
\description{
  Internal functions for pcurve
}
\keyword{internal}

\eof
